@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.6 2002/12/31 17:56:54 daniel Exp $ */
+/* $Id: generate_defs_gtk.cc,v 1.7 2003/01/05 16:10:35 murrayc Exp $ */
 
 /* generate_defs_gtk.cc
  *
@@ -48,6 +48,8 @@ int main (int argc, char *argv[])
 
   std::cout << get_defs( GDK_TYPE_COLORMAP )
             << get_defs( GDK_TYPE_DRAG_CONTEXT )
+            << get_defs( GDK_TYPE_DISPLAY )
+            << get_defs( GDK_TYPE_DISPLAY_MANAGER )
             << get_defs( GDK_TYPE_DRAWABLE )
             << get_defs( GDK_TYPE_GC )
             << get_defs( GDK_TYPE_IMAGE )
@@ -55,6 +57,7 @@ int main (int argc, char *argv[])
             << get_defs( GDK_TYPE_PIXBUF_ANIMATION )
             << get_defs( GDK_TYPE_PIXBUF_LOADER )
             << get_defs( GDK_TYPE_PIXMAP )
+            << get_defs( GDK_TYPE_SCREEN )
             << get_defs( GDK_TYPE_VISUAL )
             << get_defs( GDK_TYPE_WINDOW )
 
